@@ -1,6 +1,3 @@
-# Original authors: don
-# $Revision: 1595 $
-
 # Copyright (c) 2010 Don Owens <don@regexguy.com>.  All rights reserved.
 #
 # This is free software; you can redistribute it and/or modify it under
@@ -14,7 +11,6 @@
 # warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 # PURPOSE.
 
-
 =pod
 
 =head1 NAME
@@ -35,7 +31,7 @@ Pod::POM::View::Restructured - View for Pod::POM that outputs reStructuredText
 
 This module outputs reStructuredText that is expected to be used
 with Sphinx.  Verbatim sections (indented paragraphs) in the POD
-will be output with syntax hilighting for Perl code by default.
+will be output with syntax highlighting for Perl code by default.
 See L</"POD commands specifically for reStructuredText"> for how
 to change this for a particular block.
 
@@ -54,7 +50,7 @@ use Pod::POM;
 
 package Pod::POM::View::Restructured;
 
-our $VERSION = '0.02'; # change in POD below!
+our $VERSION = '0.03'; # change in POD below!
 
 use base 'Pod::POM::View::Text';
 
@@ -72,6 +68,12 @@ Constructor.  \%params is optional.  If present, the following keys are valid:
 
 See documentation below for C<convert_file()>.
 
+=item C<namespace>
+
+If a namespace is declared then links to that namespace are
+converted to cross references and an anchor is added for each
+head tag.
+
 =back
 
 =cut
@@ -85,7 +87,8 @@ sub new {
     my $callbacks = $params->{callbacks};
     $callbacks = { } unless $callbacks;
     $self->{callbacks} = $callbacks;
-    
+    $self->{namespace} = delete($params->{namespace});
+
     return $self;
 }
 
@@ -116,7 +119,7 @@ sub convert_file {
         $cb = $self->{callbacks};
     }
     
-    my $view = Pod::POM::View::Restructured->new({ callbacks => $cb });
+    my $view = Pod::POM::View::Restructured->new({ callbacks => $cb, namespace => $self->{namespace} });
     my $parser = Pod::POM->new;
 
     unless (-r $source_file) {
@@ -354,6 +357,16 @@ sub _build_header {
         $header = $line . "\n" . $header;
     }
 
+    my $namespace = $self->{namespace};
+    if($namespace) {
+            my $a = $text;
+            # prepend the namesspace to gaurantee document wide unique names
+            $a = "$namespace\:\:$a" unless($text =~ /^$namespace/);
+            $a =~ s/(?:\s)/-/g;
+
+            $header = qq{.. _$a:\n\n} .  $header;
+    }
+
     return "\n" . $header;
 }
 
@@ -587,6 +600,11 @@ sub view_seq_link {
         }
     }
 
+    my $url    = '';
+    my $label  = '';
+    my $module = $text;
+    my $namespace = $self->{namespace};
+
     if ($text =~ m{\A/(.+)}) {
         (my $section = $1) =~ s/\A"(.+)"/$1/;
         $text = qq{`$section`_};
@@ -595,16 +613,23 @@ sub view_seq_link {
         $text = qq{`$text <$text>`_};
     }
     elsif ($text =~ /::/) {
-        my $label = $text;
-        my $module = $text;
+        $label = $text;
         if ($text =~ /\A(.+?)\|(.+::.+)/) {
             $label = $1;
             $module = $2;
         }
 
-        $module = $self->_url_encode($module);
-        my $url = "http://search.cpan.org/search?query=$module&mode=module";
-        $text = qq{`$label <$url>`_};
+        # Links in this namespace are cross refereneces
+        if (($namespace) and ($text =~ /^$namespace/)) {
+            $module = qq{$namespace\:\:$module} unless($module =~ /^$namespace/);
+            $module =~ s/(?:\s)/-/g;
+            $text = qq{:ref:`$label <$module>`};
+        }
+        else {
+            $module = $self->_url_encode($module);
+            my $url = "http://search.cpan.org/search?query=$module&mode=module";
+            $text = qq{`$label <$url>`_};
+        }
     }
     
     return $text;
@@ -628,10 +653,10 @@ The following sequences can be used in POD to request actions specifically for t
 =head2 =Z<>for pod2rst next-code-block: I<lang>
 
 This sets up the next verbatim section, i.e., the next indented
-paragraph to be hilighted according to the syntax of the
+paragraph to be highlighted according to the syntax of the
 programming/markup/config language I<lang>.  Verbatim sections
 are assumed to be Perl code by default.  Sphinx uses Pygments to
-do syntax hilighting in these sections, so you can use any value
+do syntax highlighting in these sections, so you can use any value
 for I<lang> that Pygments supports, e.g., Python, C, C++,
 Javascript, SQL, etc.
 
@@ -660,13 +685,13 @@ B<Need to document:>
 
 =over 4
 
-=item code hilighting
+=item code highlighting
 
 Currently, a verbatim block (indented paragraph) gets output as a
 Perl code block by default in reStructuredText. There should be
 an option (e.g., in the constructor) to change the language for
-hilighting purposes (for all verbatim blocks), or disable syntax
-hilighting and just make it a preformatted paragraph.  There is a
+highlighting purposes (for all verbatim blocks), or disable syntax
+highlighting and just make it a preformatted paragraph.  There is a
 way to do this in POD (see L</"POD commands specifically for reStructuredText">),
 but there should also be an option in the constructor.
 
@@ -681,13 +706,20 @@ to invoke a command in reStructuredText by accident.
 
 Inherits from L<Pod::POM::View::Text> that comes with the Pod::POM distribution.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Don Owens <don@regexguy.com>
+=over
+
+=item Don Owens <don@regexguy.com>
+
+=item Jeff Fearn <Jeff.Fearn@gmail.com>
+
+=back
 
 =head1 LICENSE AND COPYRIGHT
 
 Copyright (c) 2010 Don Owens <don@regexguy.com>.  All rights reserved.
+Copyright (c) 2016 Jeff Fearn <Jeff.Fearn@gmail.com>.  All rights reserved.
 
 This is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.  See perlartistic.
@@ -713,7 +745,7 @@ Pygments (used by Sphinx for syntax highlighting): L<http://pygments.org/>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
 
